@@ -8,9 +8,9 @@ from dialect.define import RES_PATH
 from dialect.settings import Settings
 
 
-@Gtk.Template(resource_path=f'{RES_PATH}/shortcuts.ui')
+@Gtk.Template(resource_path=f"{RES_PATH}/shortcuts.ui")
 class DialectShortcutsWindow(Gtk.ShortcutsWindow):
-    __gtype_name__ = 'DialectShortcutsWindow'
+    __gtype_name__ = "DialectShortcutsWindow"
 
     translate_shortcut = Gtk.Template.Child()
 
@@ -19,6 +19,6 @@ class DialectShortcutsWindow(Gtk.ShortcutsWindow):
 
     @Gtk.Template.Callback()
     def _on_show(self, _data):
-        """ Called on self::show signal """
+        """Called on self::show signal"""
         self.translate_shortcut.props.visible = not Settings.get().live_translation
         self.translate_shortcut.props.accelerator = Settings.get().translate_accel
